<?php

/* Customize Appearance Options */
if ( !function_exists( 'kuist_customizer' ) ) {
	function kuist_customizer( $wp_customize ) {

		/* Font Selector */
		class kuist_font_selector extends WP_Customize_Control {

			public $type = 'select';

			public function render_content() { ?>

				<label>
					<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
					<span class="customize-control-description"><?php echo wp_kses_post( $this->description ); ?></span>
					<select <?php $this->link(); ?>>
						<?php
						foreach ( kuist_font_labels() as $key => $val ) {
							$add_underscore = str_replace( ' ', '_', $key ); ?>
							<option value="<?php echo esc_attr( $add_underscore ); ?>" <?php if( $this->value() == $add_underscore ) echo 'selected="selected"'; ?>><?php echo esc_html( $key ); ?></option>
						<?php } ?>
					</select>
				</label>

			<?php }

		}
		/* */

		/* Radio Selector */
		class kuist_radio_selector extends WP_Customize_Control {

			public $type = 'radio-image';

			public function render_content() { ?>

				<div id="<?php echo esc_attr( "input_{$this->id}" ); ?>" class="radio-selector-container">
					<span class="radio-selector-label"><?php echo esc_html( $this->label ); ?></span><br />
					<?php foreach ( $this->choices as $val => $args ) : ?>
						<input type="radio" value="<?php echo esc_attr( $val ); ?>" name="<?php echo esc_attr( "_customize-radio-{$this->id}" ); ?>" id="<?php echo esc_attr( "{$this->id}-{$val}" ); ?>" <?php $this->link(); ?> <?php checked( $this->value(), $val ); ?> />
						<label for="<?php echo esc_attr( "{$this->id}-{$val}" ); ?>"><img src="<?php echo esc_url( sprintf( $args['url'], get_template_directory_uri(), get_stylesheet_directory_uri() ) ); ?>" alt="<?php echo esc_attr( $args['label'] ); ?>" /></label>
					<?php endforeach; ?>
				</div>

			<?php }

		}
		/* */

		/* Text Area */
		class kuist_textarea extends WP_Customize_Control {

			public $type = 'textarea';

			public function render_content() { ?>
				<label>
					<span class="customize-control-description"><?php echo wp_kses_post( $this->description ); ?></span>
					<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
					<textarea rows="8" class="widefat no-resize" <?php esc_url( $this->link() ); ?>><?php echo wp_kses_post( $this->value() ); ?></textarea>
				</label>
			<?php }

		}
		/* */

		/* Sanitizers */
		function kuist_get_font_list() {
			$font_list = array();
			foreach ( kuist_font_labels() as $key => $val ) {
				$add_underscore = str_replace( ' ', '_', $key );
				$font_list[] = esc_html( $add_underscore );
			}
			return $font_list;
		}

		function kuist_sanitize_fonts( $input ) {
			$current_font_list = kuist_get_font_list();
			return ( in_array( $input, $current_font_list ) ? $input : 'null' );
		}

		function kuist_sanitize_file( $file, $setting ) {
			$mimes = array(
				'jpg|jpeg|jpe' => 'image/jpeg',
				'gif'          => 'image/gif',
				'png'          => 'image/png'
			);
			$file_ext = wp_check_filetype( $file, $mimes );
			return ( $file_ext['ext'] ? $file : $setting->default );
		}

		function kuist_sanitize_null( $input ) {
			return 0;
		}

		function kuist_sanitize_let_html( $input ) {
			return force_balance_tags( wp_kses_post( $input ) );
		}

		function kuist_sanitize_checkbox( $input ) {
			if ( $input == 1 ) {
				return 1;
			} else {
				return '';
			}
		}

		function kuist_sanitize_choices( $input, $setting ) {
			global $wp_customize;
			$control = $wp_customize->get_control( $setting->id );
			if ( array_key_exists( $input, $control->choices ) ) {
				return $input;
			} else {
				return $setting->default;
			}
		}

		function kuist_sanitize_integer( $input ) {
			if( is_numeric( $input ) ) {
				return intval( $input );
			}
		}
		/* */

		/* Customizer Styles */
		function kuist_print_styles() { ?>

			<style type="text/css">
			.radio-selector-label { font-weight: 500; font-size: 14px; }
			.radio-selector-container label { display: inline-block; cursor: pointer; margin: 7px 5px 0 0; }
			.radio-selector-container label img { border: 2px solid #EEE; }
			.radio-selector-container input[type="radio"] { position: absolute; left: -9999px; }
			.radio-selector-container input[type="radio"]:checked + label img { border: 2px solid #333; }
			</style>

		<?php }
		add_action( 'customize_controls_print_styles', 'kuist_print_styles' );
		/* */

		/* Allowed HTML */
		$kuist_allowed_html = array(
			'a' => array(
				'href' => array(),
				'target' => array(),
			),
			'span' => array(
				'class' => array(),
			),
			'br' => array(),
			'em' => array(),
			'strong' => array(),
		);
		/* */

		////////////////////////////////////////////////////
		/*/////////////////// SECTIONS ///////////////////*/
		////////////////////////////////////////////////////

		$wp_customize->add_section( 'kuist_section_header', array( 'title' => esc_html__( 'Header', 'kuist' ), 'priority' => 0, ) );
		$wp_customize->add_section( 'kuist_section_portfolio', array( 'title' => esc_html__( 'Portfolio Settings', 'kuist' ), 'priority' => 1, ) );
		$wp_customize->add_section( 'kuist_section_colors', array( 'title' => esc_html__( 'Colors', 'kuist' ), 'priority' => 2, ) );
		$wp_customize->add_section( 'kuist_section_fonts', array( 'title' => esc_html__( 'Font Settings', 'kuist' ), 'priority' => 3, ) );
		$wp_customize->add_section( 'kuist_section_contact', array( 'title' => esc_html__( 'Contact Pane', 'kuist' ), 'priority' => 4, ) );
		$wp_customize->add_section( 'kuist_section_blog', array( 'title' => esc_html__( 'Blog & Page Settings', 'kuist' ), 'priority' => 5, ) );
		$wp_customize->add_section( 'kuist_section_social', array( 'title' => esc_html__( 'Social Accounts', 'kuist' ), 'description' => wp_kses( __( 'Write the entire URL addresses.<br>Leave blank if not preferred.', 'kuist' ), $kuist_allowed_html ), 'priority' => 6, ) );
		$wp_customize->add_section( 'kuist_section_translation', array( 'title' => esc_html__( 'Translation', 'kuist' ), 'priority' => 7, ) );

		////////////////////////////////////////////////////
		/*/////////////////// SETTINGS ///////////////////*/
		////////////////////////////////////////////////////

		/* Header */
		$wp_customize->add_setting( 'kuist_logo_image', array( 'sanitize_callback' => 'kuist_sanitize_file' ) );
		$wp_customize->add_setting( 'kuist_max_logo_height', array( 'default' => 50, 'sanitize_callback' => 'kuist_sanitize_integer' ) );
		$wp_customize->add_setting( 'kuist_show_logotext', array( 'default' => 1, 'sanitize_callback' => 'kuist_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'kuist_mobile_logo_image', array( 'sanitize_callback' => 'kuist_sanitize_file' ) );
		$wp_customize->add_setting( 'kuist_trigger_slick_nav', array( 'default' => 1100, 'sanitize_callback' => 'kuist_sanitize_integer' ) );
		$wp_customize->add_setting( 'kuist_slicknav_apl', array( 'default' => 0, 'sanitize_callback' => 'kuist_sanitize_checkbox' ) );

		/* Colors */
		foreach ( kuist_get_colors() as $key => $val ) {

			$the_color = 'kuist_color' . esc_html( $key );
			$label = '';
			$description = ucwords( str_replace( '_', ' ', $key ) );

			$wp_customize->add_setting( $the_color, array( 'default' => $val, 'sanitize_callback' => 'sanitize_hex_color' ) );

			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $the_color,
				array(
					'label' => $label,
					'description' => $description,
					'section' => 'kuist_section_colors',
					'settings' => $the_color,
				)
			) );

		}
		/* */

		/* Portfolio Settings */
		$wp_customize->add_setting( 'kuist_thumbnail_width', array( 'default' => 0, 'sanitize_callback' => 'kuist_sanitize_integer' ) );
		$wp_customize->add_setting( 'kuist_thumbnail_height', array( 'default' => 250, 'sanitize_callback' => 'kuist_sanitize_integer' ) );
		$wp_customize->add_setting( 'kuist_show_categories', array( 'default' => 1, 'sanitize_callback' => 'kuist_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'kuist_home_series_per_page', array( 'default' => 5, 'sanitize_callback' => 'kuist_sanitize_integer' ) );
		$wp_customize->add_setting( 'kuist_archive_series_per_page', array( 'default' => 5, 'sanitize_callback' => 'kuist_sanitize_integer' ) );
		$wp_customize->add_setting( 'kuist_lightbox_size', array( 'default' => 'large', 'sanitize_callback' => 'kuist_sanitize_choices' ) );
		$wp_customize->add_setting( 'kuist_lightbox_width', array( 'default' => 0, 'sanitize_callback' => 'kuist_sanitize_integer' ) );
		$wp_customize->add_setting( 'kuist_lightbox_height', array( 'default' => 1000, 'sanitize_callback' => 'kuist_sanitize_integer' ) );
		$wp_customize->add_setting( 'kuist_lightbox_lazyload', array( 'default' => 0, 'sanitize_callback' => 'kuist_sanitize_checkbox' ) );
		/* */

		/* Font Settings */
		$wp_customize->add_setting( 'kuist_font_primary', array( 'default' => 'Heebo', 'sanitize_callback' => 'kuist_sanitize_fonts' ) );
		$wp_customize->add_setting( 'kuist_font_size_menu_item', array( 'default' => 13, 'sanitize_callback' => 'kuist_sanitize_integer' ) );
		$wp_customize->add_setting( 'kuist_font_size_post_content', array( 'default' => 13, 'sanitize_callback' => 'kuist_sanitize_integer' ) );
		$wp_customize->add_setting( 'kuist_font_size_portfolio_titles', array( 'default' => 13, 'sanitize_callback' => 'kuist_sanitize_integer' ) );
		$wp_customize->add_setting( 'kuist_font_size_small_texts', array( 'default' => 11, 'sanitize_callback' => 'kuist_sanitize_integer' ) );

		/* Social Accounts */
		foreach ( kuist_social_labels() as $val ) {

			$the_label = 'kuist_social_' . esc_html( $val );

			$wp_customize->add_setting( $the_label, array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );

			$wp_customize->add_control( $the_label, array(
				'description' => $val,
				'section' => 'kuist_section_social',
				'settings' => $the_label,
				'type' => 'text',
			) );

		}
		/* */

		/* Contact Pane */
		$wp_customize->add_setting( 'kuist_show_header_contact', array( 'default' => 1, 'sanitize_callback' => 'kuist_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'kuist_contact_text', array( 'default' => 'Your contact info here.<br>+001 321 65 98', 'sanitize_callback' => 'kuist_sanitize_let_html' ) );
		$wp_customize->add_setting( 'kuist_contact_form', array( 'default' => '', 'sanitize_callback' => 'sanitize_text_field' ) );
		/* */

		/* Blog & Page Settings */
		$wp_customize->add_setting( 'kuist_blog_layout', array( 'default' => '3col', 'sanitize_callback' => 'kuist_sanitize_choices' ) );
		$wp_customize->add_setting( 'kuist_blog_thumbnail_width', array( 'default' => 400, 'sanitize_callback' => 'kuist_sanitize_integer' ) );
		$wp_customize->add_setting( 'kuist_blog_thumbnail_height', array( 'default' => 400, 'sanitize_callback' => 'kuist_sanitize_integer' ) );
		$wp_customize->add_setting( 'kuist_blog_width', array( 'default' => 850, 'sanitize_callback' => 'kuist_sanitize_integer' ) );
		$wp_customize->add_setting( 'kuist_content_width', array( 'default' => 420, 'sanitize_callback' => 'kuist_sanitize_integer' ) );
		$wp_customize->add_setting( 'kuist_show_post_comments', array( 'default' => 1, 'sanitize_callback' => 'kuist_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'kuist_show_page_comments', array( 'default' => 1, 'sanitize_callback' => 'kuist_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'kuist_show_post_date', array( 'default' => 0, 'sanitize_callback' => 'kuist_sanitize_checkbox' ) );
		/* */

		/* Translation */
		$wp_customize->add_setting( 'kuist_ignore_pot', array( 'default' => 1, 'sanitize_callback' => 'kuist_sanitize_checkbox' ) );

		$wp_customize->add_control( 'kuist_ignore_pot', array(
			'label' => esc_html__( 'Ignore .pot file and use the translations below.', 'kuist' ),
			'section' => 'kuist_section_translation',
			'settings' => 'kuist_ignore_pot',
			'type' => 'checkbox',
		) );

		foreach ( kuist_get_terms() as $key => $val ) {

			$the_term = 'kuist_translate' . esc_html( $key );
			$label = '';

			if ( $key == '_Language' ) { $label = esc_html__( '1. Site Language', 'kuist' ); }
			if ( $key == '_Client' ) { $label = esc_html__( '2. Portfolio', 'kuist' ); }
			if ( $key == '_Previous' ) { $label = esc_html__( '3. Blog & Page', 'kuist' ); }
			if ( $key == '_Comment' ) { $label = esc_html__( '4. Post Comments', 'kuist' ); }

			$wp_customize->add_setting( $the_term, array( 'default' => $val, 'sanitize_callback' => 'sanitize_text_field' ) );

			$wp_customize->add_control( $the_term, array(
				'label' => $label,
				'description' => esc_html__( 'Original:', 'kuist' ) . ' "' . esc_html( $val ) . '"',
				'section' => 'kuist_section_translation',
				'settings' => $the_term,
				'type' => 'text',
			) );

		}
		/* */

		////////////////////////////////////////////////////
		/*/////////////////// CONTROLS ///////////////////*/
		////////////////////////////////////////////////////

		/* Header */
		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'kuist_logo_image', array(
			'label' => esc_html__( 'Logo Settings', 'kuist' ),
			'description' => esc_html__( 'Logo Image', 'kuist' ),
			'section' => 'kuist_section_header',
			'settings' => 'kuist_logo_image'
		) ) );
		$wp_customize->add_control( 'kuist_max_logo_height', array(
			'description' => esc_html__( 'Logo Image Size (Theme default: 50, Max: 50)', 'kuist' ),
			'section' => 'kuist_section_header',
			'settings' => 'kuist_max_logo_height',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 60px;',
			),
		) );
		$wp_customize->add_control( 'kuist_show_logotext', array(
			'label' => esc_html__( 'Show Logo Image & Site Name', 'kuist' ),
			'section' => 'kuist_section_header',
			'settings' => 'kuist_show_logotext',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'kuist_mobile_logo_image', array(
			'description' => esc_html__( 'Mobile Logo Image', 'kuist' ),
			'section' => 'kuist_section_header',
			'settings' => 'kuist_mobile_logo_image'
		) ) );
		$wp_customize->add_control( 'kuist_trigger_slick_nav', array(
			'label' => esc_html__( 'Menu Settings', 'kuist' ),
			'description' => esc_html__( 'Trigger mobile menu when window width is smaller than:', 'kuist' ),
			'section' => 'kuist_section_header',
			'settings' => 'kuist_trigger_slick_nav',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 60px;',
			),
		) );
		$wp_customize->add_control( 'kuist_slicknav_apl', array(
			'label' => esc_html__( 'Clickable Parent Menu Items in Mobile Menu', 'kuist' ),
			'section' => 'kuist_section_header',
			'settings' => 'kuist_slicknav_apl',
			'type' => 'checkbox'
		) );
		/* */

		/* Colors */
		//////  Executed in "SETTINGS" section. //////
		/* */

		/* Portfolio Settings */
		$wp_customize->add_control( 'kuist_thumbnail_width', array(
			'label' => esc_html__( 'Thumbnail Width', 'kuist' ),
			'description' => esc_html__( 'Write 0 to not to crop images. Default value is 0.', 'kuist' ),
			'section' => 'kuist_section_portfolio',
			'settings' => 'kuist_thumbnail_width',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'kuist_thumbnail_height', array(
			'label' => esc_html__( 'Thumbnail Height', 'kuist' ),
			'description' => esc_html__( 'Write 0 to not to crop images. Default value is 250. Min value is 200.', 'kuist' ),
			'section' => 'kuist_section_portfolio',
			'settings' => 'kuist_thumbnail_height',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'kuist_show_categories', array(
			'label' => esc_html__( 'Show Categories', 'kuist' ),
			'section' => 'kuist_section_portfolio',
			'settings' => 'kuist_show_categories',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'kuist_home_series_per_page', array(
			'label' => esc_html__( 'Portfolio Items Per Page', 'kuist' ),
			'description' => esc_html__( 'Write 0 to show all items. Default value is 5.', 'kuist' ),
			'section' => 'kuist_section_portfolio',
			'settings' => 'kuist_home_series_per_page',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'kuist_archive_series_per_page', array(
			'label' => esc_html__( 'Archive Portfolio Items Per Page', 'kuist' ),
			'description' => esc_html__( 'Write 0 to show all items. Default value is 5.', 'kuist' ),
			'section' => 'kuist_section_portfolio',
			'settings' => 'kuist_archive_series_per_page',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'kuist_lightbox_size', array(
			'label' => esc_html__( 'Lightbox Image Size', 'kuist' ),
			'section' => 'kuist_section_portfolio',
			'settings' => 'kuist_lightbox_size',
			'type' => 'radio',
			'choices' => array(
				'large' => esc_html__( 'Large', 'kuist' ),
				'full' => esc_html__( 'Full', 'kuist' ),
				'custom' => esc_html__( 'Custom Size', 'kuist' )
			)
		) );

		$wp_customize->add_control( 'kuist_lightbox_width', array(
			'label' => esc_html__( 'Lightbox Image Custom Width', 'kuist' ),
			'description' =>  wp_kses( __( 'Only used if "Custom Size" is selected above.<br>Write 0 to not to crop images. Default value is 0.<br>Use <a href="https://wordpress.org/plugins/regenerate-thumbnails/" target="_blank">Regenerate Thumbnails</a> after changing this value.', 'kuist' ), $kuist_allowed_html ),
			'section' => 'kuist_section_portfolio',
			'settings' => 'kuist_lightbox_width',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'kuist_lightbox_height', array(
			'label' => esc_html__( 'Lightbox Image Custom Height', 'kuist' ),
			'description' =>  wp_kses( __( 'Only used if "Custom Size" is selected above.<br>Write 0 to not to crop images. Default value is 1000.<br>Use <a href="https://wordpress.org/plugins/regenerate-thumbnails/" target="_blank">Regenerate Thumbnails</a> after changing this value.', 'kuist' ), $kuist_allowed_html ),
			'section' => 'kuist_section_portfolio',
			'settings' => 'kuist_lightbox_height',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'kuist_lightbox_lazyload', array(
			'label' => esc_html__( 'Lightbox Lazy Load Images', 'kuist' ),
			'section' => 'kuist_section_portfolio',
			'settings' => 'kuist_lightbox_lazyload',
			'type' => 'checkbox',
		) );
		/* */

		/* Font Settings */
		$wp_customize->add_control( new kuist_font_selector( $wp_customize, 'kuist_font_primary', array(
			'label' => esc_html__( 'Site Font', 'kuist' ),
			'section' => 'kuist_section_fonts',
			'description' =>  wp_kses( __( 'Theme default: Heebo', 'kuist' ), $kuist_allowed_html ),
			'settings' => 'kuist_font_primary'
		) ) );
		$wp_customize->add_control( 'kuist_font_size_menu_item', array(
			'label' => esc_html__( 'Font Sizes', 'kuist' ),
			'description' => esc_html__( 'Header Items (Theme default: 13)', 'kuist' ),
			'section' => 'kuist_section_fonts',
			'settings' => 'kuist_font_size_menu_item',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 60px;',
			),
		) );
		$wp_customize->add_control( 'kuist_font_size_post_content', array(
			'description' => esc_html__( 'Body (Theme default: 13)', 'kuist' ),
			'section' => 'kuist_section_fonts',
			'settings' => 'kuist_font_size_post_content',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 60px;',
			),
		) );
		$wp_customize->add_control( 'kuist_font_size_portfolio_titles', array(
			'description' => esc_html__( 'Portfolio Titles (Theme default: 13)', 'kuist' ),
			'section' => 'kuist_section_fonts',
			'settings' => 'kuist_font_size_portfolio_titles',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 60px;',
			),
		) );
		$wp_customize->add_control( 'kuist_font_size_small_texts', array(
			'description' => esc_html__( 'Small Texts (Theme default: 11)', 'kuist' ),
			'section' => 'kuist_section_fonts',
			'settings' => 'kuist_font_size_small_texts',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 60px;',
			),
		) );

		/* Social Accounts */
		//////  Executed in "SETTINGS" section. //////
		/* */

		/* Contact Pane */
		$wp_customize->add_control( 'kuist_show_header_contact', array(
			'label' => esc_html__( 'Show Contact Icon', 'kuist' ),
			'section' => 'kuist_section_contact',
			'settings' => 'kuist_show_header_contact',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( new kuist_textarea( $wp_customize, 'kuist_contact_text', array(
			'label' => esc_html__( 'Contact Text', 'kuist' ),
			'section' => 'kuist_section_contact',
			'settings' => 'kuist_contact_text',
			'type' => 'text',
		) ) );
		$wp_customize->add_control( 'kuist_contact_form', array(
			'label' => esc_html__( 'Contact Form Shortcode', 'kuist' ),
			'section' => 'kuist_section_contact',
			'settings' => 'kuist_contact_form',
			'type' => 'text',
		) );
		/* */

		/* Blog & Page Settings */
		$wp_customize->add_control( new kuist_radio_selector( $wp_customize, 'kuist_blog_layout', array(
			'section' => 'kuist_section_blog',
			'settings' => 'kuist_blog_layout',
			'choices' => array(
				'2col' => array( 'url' => get_template_directory_uri() . '/css/images/2col.png', 'label' => '2 Columns' ),
				'3col' => array( 'url' => get_template_directory_uri() . '/css/images/3col.png', 'label' => '3 Columns' ),
			)
		) ) );
		$wp_customize->add_control( 'kuist_blog_thumbnail_width', array(
			'label' => esc_html__( 'Thumbnail Width', 'kuist' ),
			'description' =>  wp_kses( __( 'Write 0 to not to crop images. Default value is 400.<br>Use <a href="https://wordpress.org/plugins/regenerate-thumbnails/" target="_blank">Regenerate Thumbnails</a> after changing this value.', 'kuist' ), $kuist_allowed_html ),
			'section' => 'kuist_section_blog',
			'settings' => 'kuist_blog_thumbnail_width',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'kuist_blog_thumbnail_height', array(
			'label' => esc_html__( 'Thumbnail Height', 'kuist' ),
			'description' =>  wp_kses( __( 'Write 0 to not to crop images. Default value is 400.<br>Use <a href="https://wordpress.org/plugins/regenerate-thumbnails/" target="_blank">Regenerate Thumbnails</a> after changing this value.', 'kuist' ), $kuist_allowed_html ),
			'section' => 'kuist_section_blog',
			'settings' => 'kuist_blog_thumbnail_height',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'kuist_blog_width', array(
			'label' => esc_html__( 'Max Container Width', 'kuist' ),
			'description' => esc_html__( 'Default value is 850.', 'kuist' ),
			'section' => 'kuist_section_blog',
			'settings' => 'kuist_blog_width',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'kuist_content_width', array(
			'label' => esc_html__( 'Content Width', 'kuist' ),
			'description' => esc_html__( 'Default value is 420.', 'kuist' ),
			'section' => 'kuist_section_blog',
			'settings' => 'kuist_content_width',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'kuist_show_post_comments', array(
			'label' => esc_html__( 'Show Post Comments', 'kuist' ),
			'section' => 'kuist_section_blog',
			'settings' => 'kuist_show_post_comments',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'kuist_show_page_comments', array(
			'label' => esc_html__( 'Show Page Comments', 'kuist' ),
			'section' => 'kuist_section_blog',
			'settings' => 'kuist_show_page_comments',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'kuist_show_post_date', array(
			'label' => esc_html__( 'Show Post Date', 'kuist' ),
			'section' => 'kuist_section_blog',
			'settings' => 'kuist_show_post_date',
			'type' => 'checkbox',
		) );
		/* */

		/* Translation */
		//////  Executed in "SETTINGS" section. //////
		/* */

	}
}
add_action( 'customize_register', 'kuist_customizer' );

?>
