<?php

if ( !isset( $content_width ) ) {
	$content_width = 2560;
}

/* Include Customizer */
include( get_template_directory() . '/customizer.php' );
/* */

/* Google Fonts */
include( get_template_directory() . '/lib/google-fonts.php' );

if ( !function_exists( 'kuist_fonts_url' ) ) {
	function kuist_fonts_url() {

		$font_customizer_names = array();

		foreach ( kuist_font_labels() as $key => $val ) {

			$add_underscore = str_replace( ' ', '_', $key );
			$font_customizer_names[ $add_underscore ] = $key . ':300,300i,400,400i,500,500i,600,600i,700,700i';

		}

		$font_holders = array(
			get_theme_mod( 'kuist_font_primary', 'Heebo' ),
		);

		$font_families = array();

		foreach ( $font_customizer_names as $n => $g ) {
			foreach ( $font_holders as $fh ) {
				if( $n == $fh ) {
					if ( !in_array( $g, $font_families ) ) {
						$font_families[] = $g;
					}
				}
			}
		}

		$query_args = array(
			'family' => urlencode( implode( '|', $font_families ) ),
		);

		$fonts_url = add_query_arg( $query_args, '//fonts.googleapis.com/css' );
		return esc_url_raw( $fonts_url );

	}
}
/* */

/* Embed Resources */
if ( !function_exists( 'kuist_embed_resources' ) ) {
	function kuist_embed_resources() {

		/* Fonts */
		wp_enqueue_style( 'kuist-fonts', kuist_fonts_url(), array(), null );
		/* */

		/* .css */
		wp_enqueue_style( 'normalize', get_template_directory_uri() . '/css/normalize.css', array( 'kuist-fonts' ) );
		wp_enqueue_style( 'kuist-style', get_stylesheet_uri() );
		wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/css/fontawesome-all.min.css', array( 'kuist-style' ), '', 'all' );
		wp_enqueue_style( 'swiper', get_template_directory_uri() . '/css/swiper.min.css', array(), '', 'all' );
		wp_enqueue_style( 'kuist-responsive', get_template_directory_uri() . '/css/responsive.css', array(), '', 'all' );
		wp_enqueue_style( 'slicknav', get_template_directory_uri() . '/css/slicknav.css', array(), '', 'all' );
		wp_add_inline_style( 'slicknav', kuist_rewrite_css() );
		/* */

		/* .js */
		wp_enqueue_script( 'fitvids', get_template_directory_uri() . '/js/jquery.fitvids.js', array( 'jquery' ), '', true );
		wp_enqueue_script( 'swiper', get_template_directory_uri() . '/js/swiper.min.js', array( 'jquery' ), '', true );
		wp_enqueue_script( 'kuist-burnhambox', get_template_directory_uri() . '/js/burnhambox.js', array( 'jquery' ), '', true );
		wp_enqueue_script( 'slicknav', get_template_directory_uri() . '/js/jquery.slicknav.min.js', array( 'jquery' ), '', true );
		/* */

		/* comment-reply Tag */
		if ( is_singular() && comments_open() ) {
			wp_enqueue_script( 'comment-reply' );
		}
		/* */

	}
}
add_action( 'wp_enqueue_scripts', 'kuist_embed_resources' );

if ( !function_exists( 'kuist_call_loadmore' ) ) {
	function kuist_call_loadmore( $q ) {

		wp_register_script( 'flexport-loadmore', get_template_directory_uri() . '/js/flexport-loadmore.js', array( 'jquery' ) );

	  wp_localize_script( 'flexport-loadmore', 'flexport_loadmore_params', array(
	    'ajaxurl' => site_url() . '/wp-admin/admin-ajax.php',
	    'posts' => json_encode( $q->query_vars ),
	    'current_page' => get_query_var( 'paged' ) ? get_query_var( 'paged' ) : 1,
	    'max_page' => $q->max_num_pages
	  ) );

	  wp_enqueue_script( 'flexport-loadmore' );

	}
}
/* */

/* Theme setup */
if ( !function_exists( 'kuist_theme_setup' ) ) {
	function kuist_theme_setup() {

		// Navigation Menu
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary Menu', 'kuist' ),
			'footer' => esc_html__( 'Footer Menu', 'kuist' ),
		) );

		$kuist_thumbnail_width = get_theme_mod( 'kuist_thumbnail_width', 0 );
		$kuist_thumbnail_height = get_theme_mod( 'kuist_thumbnail_height', 250 );
		if ( $kuist_thumbnail_height < 200 ) { $kuist_thumbnail_height = 200; }
		$kuist_lightbox_width = get_theme_mod( 'kuist_lightbox_width', 0 );
		$kuist_lightbox_height = get_theme_mod( 'kuist_lightbox_height', 1000 );
		$kuist_blog_thumbnail_width = get_theme_mod( 'kuist_blog_thumbnail_width', 400 );
		$kuist_blog_thumbnail_height = get_theme_mod( 'kuist_blog_thumbnail_height', 400 );

		// Add featured image support. Works for only new added images.
		add_theme_support( 'post-thumbnails' );
		add_image_size( 'kuist-series-thumbnail', $kuist_thumbnail_width, $kuist_thumbnail_height, array( 'top', 'middle' ) );
		add_image_size( 'kuist-lightbox-thumb', $kuist_lightbox_width, $kuist_lightbox_height, array( 'top', 'middle' ) );
		add_image_size( 'kuist-blog-thumbnail', $kuist_blog_thumbnail_width, $kuist_blog_thumbnail_height, array( 'top', 'middle' ) );

		// Add automatic feed links support
		add_theme_support( 'automatic-feed-links' );

		// Add title-tag support
		add_theme_support( 'title-tag' );

		// Add text-domain
		load_theme_textdomain( 'kuist', get_template_directory() . '/languages ');

		// Add wide images support for Gutenberg
		add_theme_support( 'align-wide' );

	}
}
add_action( 'after_setup_theme', 'kuist_theme_setup' );
/* */

/* Clear White Space */
if ( !function_exists( 'kuist_compress' ) ) {
	function kuist_compress( $buffer ) {

		$buffer = preg_replace( '~>\s+<~', '><', $buffer );
		return $buffer;

	}
}
/* */

/* Add responsive container to embeds for wordpress.tv */
if ( !function_exists( 'kuist_embed_html' ) ) {
	function kuist_embed_html( $html ) {

		$html = preg_replace(
			array(
				'{<embed src="//v.wordpress}',
				'{wmode="transparent">}'
			),
			array(
				'<div class="video-container"><embed src="//v.wordpress',
				'wmode="transparent"></div>'
			), $html
		);

		return $html;

	}
}
add_filter( 'embed_oembed_html', 'kuist_embed_html', 10, 3 );
/* */

/* Content Filter */
if ( !function_exists( 'kuist_filter_content' ) ) {
	function kuist_filter_content( $content ) {

		// Add "to_fit_vids class" to iframes to make the videos responsive in posts
		// Convert self hosted videos to HTML5
		$content = preg_replace(
			array(
				'{<iframe}',
				'{</iframe>}',
				'/\[video(.+?(?=http))/',
				'/\]\[\/video]/',
			),
			array(
				'<div class="to_fit_vids"><iframe',
				'</iframe></div>',
				'<div class="to_fit_vids"><video controls><source src="',
				' type="video/mp4"></video></div>',
			),
			$content
		);

		return $content;

	}
}
add_filter( 'the_content', 'kuist_filter_content' );
/* */

/* Formatting the content like "the_content" while using "get_the_content" */
if ( !function_exists( 'kuist_format_get_the_content' ) ) {
	function kuist_format_get_the_content( $more_link_text = null, $stripteaser = false ) {

		$content = get_the_content( $more_link_text, $stripteaser );
		$content = apply_filters( 'the_content', $content );
		return $content;

	}
}
/* */

/* Excerpt Length */
if ( !function_exists( 'kuist_excerpt_length' ) ) {
	function kuist_excerpt_length( $length ) {
	    return 40;
	}
}
add_filter( 'excerpt_length', 'kuist_excerpt_length', 999 );
/* */

/* HEX to RGB */
if ( !function_exists( 'kuist_hex2rgb' ) ) {
	function kuist_hex2rgb( $hex ) {

		$hex = str_replace( '#', '', $hex );

		if ( strlen( $hex ) == 3 ) {

			$r = hexdec( substr( $hex, 0, 1 ).substr( $hex, 0, 1 ) );
			$g = hexdec( substr( $hex, 1, 1).substr( $hex, 1, 1 ) );
			$b = hexdec( substr( $hex, 2, 1).substr( $hex, 2, 1 ) );

		} else {

			$r = hexdec( substr( $hex, 0, 2 ) );
			$g = hexdec( substr( $hex, 2, 2 ) );
			$b = hexdec( substr( $hex, 4, 2 ) );

		}

		$rgb = array( $r, $g, $b );
		return implode( ',', $rgb );

	}
}
/* */

/* Nothing Found */
if ( !function_exists( 'kuist_nothing_found' ) ) {
	function kuist_nothing_found() {

		$template = '<div class="nothing-found"><i class="fas fa-ban"></i>' . esc_html( kuist_translation( '_NothingFound' ) ) . '</div>';
		return $template;

	}
}
/* */

/* Translation */
if ( !function_exists( 'kuist_get_terms' ) ) {
	function kuist_get_terms() {

		$terms = array(
			'_Language' => get_bloginfo( 'language' ),
			'_Client' => esc_html__( 'Client', 'kuist' ),
			'_Agency' => esc_html__( 'Agency', 'kuist' ),
			'_Photographer' => esc_html__( 'Photographer', 'kuist' ),
			'_Retoucher' => esc_html__( 'Retoucher', 'kuist' ),
			'_Artist' => esc_html__( 'Artist', 'kuist' ),
			'_MakeUp' => esc_html__( 'Make-Up', 'kuist' ),
			'_Date' => esc_html__( 'Date', 'kuist' ),
			'_Other' => esc_html__( 'Other', 'kuist' ),
			'_Close' => esc_html__( 'CLOSE', 'kuist' ),
			'_All' => esc_html__( 'ALL', 'kuist' ),
			'_Previous' => esc_html__( 'PREVIOUS', 'kuist' ),
			'_Next' => esc_html__( 'NEXT', 'kuist' ),
			'_Page' => esc_html__( 'PAGE', 'kuist' ),
			'_404' => esc_html__( 'PAGE NOT FOUND.', 'kuist' ),
			'_404Warning' => esc_html__( 'The page you are looking for has been either removed or never existed.', 'kuist' ),
			'_NothingFound' => esc_html__( 'NOTHING FOUND.', 'kuist' ),
			'_Archives' => esc_html__( 'ARCHIVES', 'kuist' ),
			'_Comment' => esc_html__( 'Comment', 'kuist' ),
			'_Comments' => esc_html__( 'Comments', 'kuist' ),
			'_Name' => esc_html__( 'Name', 'kuist' ),
			'_Email' => esc_html__( 'E-mail', 'kuist' ),
			'_MustBeLogged' => esc_html__( 'You must be logged in to post a comment.', 'kuist' ),
			'_Logged' => esc_html__( 'Logged In', 'kuist' ),
			'_LogOut' => esc_html__( 'Log Out', 'kuist' ),
			'_LeaveReply' => esc_html__( 'LEAVE A REPLY', 'kuist' ),
			'_CancelReply' => esc_html__( 'Cancel Reply', 'kuist' ),
			'_PostComment' => esc_html__( 'POST COMMENT', 'kuist' ),
			'_At' => esc_html__( 'at', 'kuist' ),
			'_Reply' => esc_html__( 'REPLY', 'kuist' ),
			'_Edit' => esc_html__( 'EDIT', 'kuist' ),
			'_Awaiting' => esc_html__( 'Comment awaiting approval.', 'kuist' ),
			'_Cookie' => esc_html__( 'Save my name, email, and website in this browser for the next time I comment', 'kuist' ),
		);

		return $terms;

	}
}

if ( !function_exists( 'kuist_translation' ) ) {
	function kuist_translation( $term ) {

		$the_term = 'kuist_translate' . esc_html( $term );

		foreach ( kuist_get_terms() as $key => $val ) {
			if ( $key == $term ) {
				if ( get_theme_mod( 'kuist_ignore_pot', 1 ) ) {
					$$the_term = get_theme_mod( $the_term, $val );
				} else {
					$$the_term = esc_html( $val );
				}
				break;
			}
		}

		return $$the_term;

	}
}
/* */

/* Assign Menu Warnings */
if ( !function_exists( 'kuist_assign_primary_menu' ) ) {
	function kuist_assign_primary_menu() {
		echo '<div class="assign-menu">' . esc_html__( 'Please assign a Primary Menu.', 'kuist' ) . '</div>';
	}
}

if ( !function_exists( 'kuist_assign_footer_menu' ) ) {
	function kuist_assign_footer_menu() {
		echo '<div class="assign-menu footer-nav"></div>';
	}
}
/* */

/* Apply column options */
if ( !function_exists( 'kuist_apply_columns' ) ) {
	function kuist_apply_columns() {

		/* Radio Default Values */
		$kuist_blog_layout = get_theme_mod( 'kuist_blog_layout', '3col' );
		/* */

		if ( $kuist_blog_layout == '2col' ) {

			// 2 Columns
			$column = 'col-1-2';

		} else if ( $kuist_blog_layout == '3col' ) {

			// 3 Columns
			$column = 'col-1-3';

		}

		return $column;

	}
}
/* */

/* Pagination */
if ( !function_exists( 'kuist_page_navigation' ) ) {
	function kuist_page_navigation() {

		global $the_query;

		if ( $the_query->max_num_pages > 1 ) {
			return '<div class="kuist_loadmore kuist-circle-button"><div class="lm_horizontal"></div><div class="lm_vertical"></div></div>';
		}

	}
}

if ( !function_exists( 'kuist_posts_navigation' ) ) {
	function kuist_posts_navigation() {

		global $wp_query;
		$kuist_big = 999999999; // need an unlikely integer
		$kuist_current_query_mnp = $wp_query->max_num_pages;

		$kuist_paginate_links = paginate_links( array(

			'base' => str_replace( $kuist_big, '%#%', esc_url( get_pagenum_link( $kuist_big ) ) ),
			'format' => '?paged=%#%',
			'current' => max( 1, get_query_var( 'paged' ) ),
			'total' => $kuist_current_query_mnp,
			'prev_next' => false,
			'end_size' => 1,
			'mid_size' => 1

		) );

		if ( $kuist_paginate_links ) {

			echo '<div class="pagenavi clearfix">';
			echo wp_kses_post( $kuist_paginate_links );
			echo '</div>';

		}

	}
}

if ( !function_exists( 'kuist_post_navigation' ) ) {
	function kuist_post_navigation( $direction, $posting, $term ) {

		$post_navigation = '';

		if( $posting ) {
			$post_navigation .= '<a class="post-navi-' . esc_attr( $direction ) . ' clearfix" href="' . get_permalink( $posting->ID ) . '">' . esc_html( $term ) . '</a>';
		}

		return $post_navigation;

	}
}
/* */

/* Load More */
if ( !function_exists( 'kuist_loadmore_ajax_handler' ) ) {
	function kuist_loadmore_ajax_handler() {

		$args = json_decode( stripslashes( $_POST['query'] ), true );
		$args['paged'] = $_POST['page'] + 1;
		$args['post_status'] = 'publish';
		$kuist_series_number = 0;

		global $wp_query;

		query_posts( $args );

		if( have_posts() ) {
			while( have_posts() ) {

				the_post();

				$kuist_series_number ++;
		    $kuist_content = kuist_call_slide_content( ( $args['posts_per_page'] * ( $args['paged'] - 1 ) ) + $kuist_series_number, get_the_title(), 'sc_' . esc_attr( $args['paged'] ), get_post_meta( get_the_ID(), 'flexport_gallery_id', true ), get_post_meta( get_the_ID(), 'flexport_fields_client', true ), get_post_meta( get_the_ID(), 'flexport_fields_agency', true ), get_post_meta( get_the_ID(), 'flexport_fields_photographer', true ), get_post_meta( get_the_ID(), 'flexport_fields_retoucher', true ), get_post_meta( get_the_ID(), 'flexport_fields_artist', true ), get_post_meta( get_the_ID(), 'flexport_fields_makeup', true ), get_post_meta( get_the_ID(), 'flexport_fields_date', true ), get_post_meta( get_the_ID(), 'flexport_fields_other', true ) );
				echo wp_kses_post( $kuist_content );

			}
		}

		die;

	}
}
add_action('wp_ajax_loadmore', 'kuist_loadmore_ajax_handler');
add_action('wp_ajax_nopriv_loadmore', 'kuist_loadmore_ajax_handler');

if ( !function_exists( 'kuist_call_slide_content' ) ) {
	function kuist_call_slide_content( $num, $title, $container, $result, $client, $agency, $photographer, $retoucher, $artist, $makeup, $date, $other ) {

		$data_client = ' data-client="';
		$data_agency = ' data-agency="';
		$data_photographer = ' data-photographer="';
		$data_retoucher = ' data-retoucher="';
		$data_artist = ' data-artist="';
		$data_makeup = ' data-makeup="';
		$data_date = ' data-date="';
		$data_other = ' data-other="';

		if ( $client ) { $data_client .= $client . '"'; } else { $data_client = ''; }
		if ( $agency ) { $data_agency .= $agency . '"'; } else { $data_agency = ''; }
		if ( $photographer ) { $data_photographer .= $photographer . '"'; } else { $data_photographer = ''; }
		if ( $retoucher ) { $data_retoucher .= $retoucher . '"'; } else { $data_retoucher = ''; }
		if ( $artist ) { $data_artist .= $artist . '"'; } else { $data_artist = ''; }
		if ( $makeup ) { $data_makeup .= $makeup . '"'; } else { $data_makeup = ''; }
		if ( $date ) { $data_date .= $date . '"'; } else { $data_date = ''; }
		if ( $other ) { $data_other .= $other . '"'; } else { $data_other = ''; }

		$first_letter = substr( $title, 0, 1 );

		$content = '<div class="swiper-container ' . esc_attr( $container ) . '"><div class="drag-notifier kuist-circle-button"></div><div class="swiper-wrapper" data-title="' . esc_attr( $title ) . '" ' . wp_kses_post( $data_client ) . wp_kses_post( $data_agency ) . wp_kses_post( $data_photographer ) . wp_kses_post( $data_retoucher ) . wp_kses_post( $data_artist ) . wp_kses_post( $data_makeup ) . wp_kses_post( $data_date ) . wp_kses_post( $data_other ) . ' data-series="' . esc_attr( $container ) . '_series_' . esc_attr( $num ) . '">';
		$content .= '<div class="swiper-slide kuist-title sswt"><div class="kuist-title-holder"><div class="kuist-letter">' . esc_html( $first_letter ) . '<div class="kuist-title-num">' . esc_html( $num ) . '</div></div><div class="kuist-title-inner">' . esc_html( $title ) . '</div></div></div>';

		$images = '';
		$lightbox_size = get_theme_mod( 'kuist_lightbox_size', 'large' );
		if ( $lightbox_size == 'custom' ) { $lightbox_size = 'kuist-lightbox-thumb'; }

		if ( $result ) {
			foreach ( $result as $key=>$val ) {

				$img = wp_get_attachment_image_src( $val, 'kuist-series-thumbnail' );
				$img_lb = wp_get_attachment_image_src( $val, $lightbox_size );
				$img_id = get_post( $val );
				$img_cap = $img_id->post_excerpt;
				$images .= '<div class="swiper-slide"><div class="kuist-mag kuist-circle-button"><i class="fas fa-search"></i></div><img data-order="' . esc_attr( $key ) . '" data-lightbox-image="' . esc_url( $img_lb[0] ) . '" data-caption="' . esc_attr( $img_cap ) . '" src="' . esc_url( $img[0] ) . '" alt="kuist-series-' . esc_attr( $key ) . '"></div>';

			}
		}

		$content .= $images;
		$content .= '</div></div>';

		return $content;

	}
}
/* */

/* Social Icons */
if ( !function_exists( 'kuist_social_labels' ) ) {
	function kuist_social_labels() {

		$labels = array(
			esc_html__( 'Facebook', 'kuist' ),
			esc_html__( 'Twitter', 'kuist' ),
			esc_html__( 'Instagram', 'kuist' ),
			esc_html__( 'Pinterest', 'kuist' ),
			esc_html__( 'Google+', 'kuist' ),
			esc_html__( 'Tumblr', 'kuist' ),
			esc_html__( 'Flickr', 'kuist' ),
			esc_html__( 'Digg', 'kuist' ),
			esc_html__( 'LinkedIn', 'kuist' ),
			esc_html__( 'Vimeo', 'kuist' ),
			esc_html__( 'YouTube', 'kuist' ),
			esc_html__( 'Behance', 'kuist' ),
			esc_html__( 'Dribbble', 'kuist' ),
			esc_html__( 'DeviantArt', 'kuist' ),
			esc_html__( 'Github', 'kuist' ),
			esc_html__( 'Lastfm', 'kuist' ),
			esc_html__( 'SoundCloud', 'kuist' ),
			esc_html__( 'VK', 'kuist' )
		);

		return $labels;

	}
}

if ( !function_exists( 'kuist_social_names' ) ) {
	function kuist_social_names() {

		$account_names = array(
			'Facebook',
			'Twitter',
			'Instagram',
			'Pinterest',
			'Google+',
			'Tumblr',
			'Flickr',
			'Digg',
			'Linkedin',
			'Vimeo',
			'Youtube',
			'Behance',
			'Dribbble',
			'Deviantart',
			'Github',
			'Bloglovin',
			'Lastfm',
			'SoundCloud',
			'VK'
		);

		return $account_names;

	}
}

if ( !function_exists( 'kuist_insert_social_icons' ) ) {
	function kuist_insert_social_icons( $location ) {

		$kuist_social_accounts = array();

		foreach ( kuist_social_labels() as $val ) {

			array_push( $kuist_social_accounts, get_theme_mod( 'kuist_social_' . esc_html( $val ) ) );

		}

		$kuist_social_faIcons = kuist_social_names();
		$kuist_social_show = false;
		$kuist_social_html = '<div class="' . esc_attr( $location ) . '">';

		foreach ( $kuist_social_accounts as $key => $sa ) {

			if ( $sa != 'http://' && $sa != '' ) {

				$kuist_social_show = true;
				$kuist_social_html .= '<a class="social-menu-item" href="' . esc_url( $sa ) . '" target="_blank">' . esc_html( $kuist_social_faIcons[ $key ] ) . '</a>';

			}

		}

		$kuist_social_html .= '</div>';

		if ( $location == 'footer-social' && !$kuist_social_show ) {

			$kuist_social_html = '<div class="' . esc_attr( $location ) . '"></div>';

		}

		return $kuist_social_html;

	}
}
/* */

/* Enqueue Gutenberg editor styles */
if ( !function_exists( 'kuist_gutenberg_styles' ) ) {
	function kuist_gutenberg_styles() {

		wp_enqueue_style( 'kuist-fonts', kuist_fonts_url(), array(), null );
		wp_enqueue_style( 'kuist-gutenberg', get_template_directory_uri() . '/css/gutenberg-editor.css', false, '@@pkg.version', 'all' );
		wp_add_inline_style( 'kuist-gutenberg', kuist_rewrite_gutenberg_editor_css() );

	}
}
add_action( 'enqueue_block_editor_assets', 'kuist_gutenberg_styles' );
/* */

/* Include the TGM_Plugin_Activation class. */
require_once get_template_directory() . '/lib/class-tgm-plugin-activation.php';

if ( !function_exists( 'kuist_register_plugins' ) ) {
	function kuist_register_plugins() {

		$plugins = array(

			/*
			Contact Form 7
			Regenerate Thumbnails
			Kuist Portfolio
			*/

			array(
				'name' => 'Contact Form 7',
				'slug' => 'contact-form-7',
				'required' => false
			),

			array(
				'name' => 'Regenerate Thumbnails',
				'slug' => 'regenerate-thumbnails',
				'required' => false
			),

			array(
				'name' => 'Kuist Portfolio',
				'slug' => 'flexport',
				'source' => get_template_directory() . '/lib/plugins/flexport.zip',
				'required' => false,
			),

		);

		$config = array(
			'id'           => 'kuist',
			'default_path' => '',
			'menu'         => 'tgmpa-install-plugins',
			'has_notices'  => true,
			'dismissable'  => true,
			'dismiss_msg'  => '',
			'is_automatic' => false,
			'message'      => '',

		);

		tgmpa( $plugins, $config );

	}
}
add_action( 'tgmpa_register', 'kuist_register_plugins' );
/* */

/* Colors */
if ( !function_exists( 'kuist_get_colors' ) ) {
	function kuist_get_colors() {

		$colors = array(
			'_background' => '#ffffff',
			'_primary_color' => '#000000',
			'_secondary_color' => '#4447ff',
			'_menu_background' => '#000000',
			'_menu_link' => '#ffffff',
			'_pane_background' => '#000000',
			'_pane_content' => '#ffffff',
		);

		return $colors;

	}
}

if ( !function_exists( 'kuist_color' ) ) {
	function kuist_color( $color ) {

		$the_color = 'kuist_color' . esc_html( $color );

		foreach ( kuist_get_colors() as $key => $val ) {
			if ( $key == $color ) {
				$$the_color = get_theme_mod( $the_color, $val );
				break;
			}
		}

		return $$the_color;

	}
}
/* */

/* Allow wp_kses */
$kuist_allowed_kses_tags = wp_kses_allowed_html( 'post' );
if ( !function_exists( 'kuist_allow_kses' ) ) {
	function kuist_allow_kses() {
		global $kuist_allowed_kses_tags;
		$kuist_allowed_kses_tags['div']['data-series'] = true;
		$kuist_allowed_kses_tags['div']['data-title'] = true;
		$kuist_allowed_kses_tags['div']['data-client'] = true;
		$kuist_allowed_kses_tags['div']['data-agency'] = true;
		$kuist_allowed_kses_tags['div']['data-photographer'] = true;
		$kuist_allowed_kses_tags['div']['data-retoucher'] = true;
		$kuist_allowed_kses_tags['div']['data-artist'] = true;
		$kuist_allowed_kses_tags['div']['data-makeup'] = true;
		$kuist_allowed_kses_tags['div']['data-date'] = true;
		$kuist_allowed_kses_tags['div']['data-other'] = true;
		$kuist_allowed_kses_tags['img']['data-order'] = true;
		$kuist_allowed_kses_tags['img']['data-lightbox-image'] = true;
		$kuist_allowed_kses_tags['img']['data-caption'] = true;
		return $kuist_allowed_kses_tags;
	}
}
add_filter( 'wp_kses_allowed_html', 'kuist_allow_kses', 10, 2 );
/* */

/* Template Switchers */
if ( !function_exists( 'kuist_switch_template' ) ) {
	function kuist_switch_template( $template ) {
		get_template_part( 'templates/template-parts/' . esc_html( $template ) . '-part' );
		global $kuist_content;
		echo wp_kses_post( $kuist_content );
	}
}
/* */

/* Output Customize CSS */
if ( !function_exists( 'kuist_rewrite_css' ) ) {
	function kuist_rewrite_css() {

		$menuContainerHeight = 50;
		$maxLogoHeight = get_theme_mod( 'kuist_max_logo_height', 50 );

		$kuist_font_size_menu_item = get_theme_mod( 'kuist_font_size_menu_item', 13 );
		$kuist_font_size_post_content = get_theme_mod( 'kuist_font_size_post_content', 13 );
		$kuist_font_size_portfolio_titles = get_theme_mod( 'kuist_font_size_portfolio_titles', 13 );
		$kuist_font_size_small_texts = get_theme_mod( 'kuist_font_size_small_texts', 11 );

		if ( $maxLogoHeight > $menuContainerHeight ) { $maxLogoHeight = $menuContainerHeight; }

		$kuist_thumbnail_height = get_theme_mod( 'kuist_thumbnail_height', 250 );
		if ( $kuist_thumbnail_height < 200 ) { $kuist_thumbnail_height = 200; }

		$css = '';

		$logo_text_ml = '';
		$taxonomy = 'portfolio_category';
		$terms = get_terms( $taxonomy );
		if ( $terms && get_theme_mod( 'kuist_show_categories', 1 ) && ( is_page_template( 'templates/works.php' ) || is_tax() ) ) {
			$css .= '.site-logo-outer { left: 50px; }';
		} else if ( !get_theme_mod( 'kuist_logo_image' ) ) {
			$logo_text_ml = 'h1.logo-text { margin-left: 20px; }';
		}

		$css .= '
			body { background-color: ' . esc_html( kuist_color( '_background' ) ) . '; color: ' . esc_html( kuist_color( '_primary_color' ) ) . '; }
			a,
			a:visited { color: ' . esc_html( kuist_color( '_primary_color' ) ) . '; }
			a:hover,
			input[type="submit"]:hover { color: ' . esc_html( kuist_color( '_secondary_color' ) ) . '; }
			footer li.menu-item-passive a:hover { color: ' . esc_html( kuist_color( '_primary_color' ) ) . '; }
			.footer-bottom { background-color: rgba(' . esc_html( kuist_hex2rgb( kuist_color( '_primary_color' ) ) ) . ', 0.04); }
			.kuist-stripes { background: repeating-linear-gradient(	120deg,	rgba(' . esc_html( kuist_hex2rgb( kuist_color( '_primary_color' ) ) ) . ', 0.05), rgba(' . esc_html( kuist_hex2rgb( kuist_color( '_primary_color' ) ) ) . ', 0.05) 1px,	' . esc_html( kuist_color( '_background' ) ) . ' 1px, ' . esc_html( kuist_color( '_background' ) ) . ' 200px ); }
			.kuist-circle-button,
			a.kuist-circle-button,
			a.kuist-circle-button:visited { background-color: ' . esc_html( kuist_color( '_background' ) ) . '; color: ' . esc_html( kuist_color( '_primary_color' ) ) . '; border-color: ' . esc_html( kuist_color( '_primary_color' ) ) . '; }
			.kuist-circle-button:hover,
			a.kuist-circle-button:hover { color: ' . esc_html( kuist_color( '_secondary_color' ) ) . '; border-color: ' . esc_html( kuist_color( '_secondary_color' ) ) . '; }
			.kuist-circle-button.current { background-color: ' . esc_html( kuist_color( '_primary_color' ) ) . '; color: ' . esc_html( kuist_color( '_background' ) ) . '; border-color: ' . esc_html( kuist_color( '_primary_color' ) ) . '; }

			@media all and (min-width: 640px) {

				.series-swiper .swiper-slide,
				.series-swiper .swiper-slide img,
				.series-swiper .swiper-slide .kuist-title-holder {
					height: ' . esc_html( $kuist_thumbnail_height ) . 'px;
				}

				.drag-notifier { top: ' . ( esc_html( $kuist_thumbnail_height )/2 - 20 ) . 'px; }
				.kuist-letter { line-height: ' . esc_html( $kuist_thumbnail_height ) . 'px; }

			}
		';

		/* Menu & Header */
		$css .= '
		.mobile-header { background-color: ' . esc_html( kuist_color( '_menu_background' ) ) . '; color: ' . esc_html( kuist_color( '_menu_link' ) ) . '; }
		.slicknav_menu a,
		.slicknav_menu a:visited { color: ' . esc_html( kuist_color( '_menu_link' ) ) . '; }

		a h1.logo-text,
		a:visited h1.logo-text,
		a:hover h1.logo-text { color: ' . esc_html( kuist_color( '_menu_link' ) ) . '; }
		';

		$css .= '
		.site-top-container-outer { background-color: ' . esc_html( kuist_color( '_menu_background' ) ) . '; color: ' . esc_html( kuist_color( '_menu_link' ) ) . '; }
		.site-nav li.current-menu-item,
		.site-nav li.current-menu-parent,
		.site-nav li:hover,
		.site-nav li ul { background: repeating-linear-gradient(	120deg,	#f1f1f1, #f1f1f1 2px,	' . esc_html( kuist_color( '_menu_link' ) ) . ' 2px, ' . esc_html( kuist_color( '_menu_link' ) ) . ' 4px ); }
		.site-nav li a,
		.site-nav li a:visited { color: ' . esc_html( kuist_color( '_menu_link' ) ) . '; }
		.site-nav li:hover a,
		.site-nav li.current-menu-item a,
		.site-nav li.current-menu-item a:visited,
		.site-nav li.current-menu-parent a,
		.site-nav li.current-menu-parent a:visited { color: ' . esc_html( kuist_color( '_menu_background' ) ) . '; }
		.site-nav li a:before { background-color: ' . esc_html( kuist_color( '_menu_background' ) ) . '; }
		.site-nav li ul li a,
		.site-nav li ul li a:visited { color: ' . esc_html( kuist_color( '_menu_background' ) ) . '; }
		';

		if ( !get_theme_mod( 'kuist_show_header_contact', 1 ) ) {
			$css .= '.top-extra-outer { margin-left: 0; }';
		}

		$css .= '
		.site-logo-outer,
		.site-logo-outer-handler,
		.top-extra { height: ' . esc_html( $menuContainerHeight ) . 'px; }
		.site-logo-container img { max-height: ' . esc_html( $maxLogoHeight ) . 'px; }
		h1.logo-text { line-height: ' . esc_html( $maxLogoHeight ) . 'px; }
		';

		/* Article */
		$css .= '
		.posts-wrapper,
		.archive-bar { max-width: ' . ( get_theme_mod( 'kuist_blog_width', 850 ) + 40 ) . 'px; }
		.kuist-content-size { max-width: ' . get_theme_mod( 'kuist_content_width', 420 ) . 'px; }
		.post-navi { max-width: ' . ( get_theme_mod( 'kuist_content_width', 420 ) + 80 ) . 'px; background-color: rgba(' . esc_html( kuist_hex2rgb( kuist_color( '_primary_color' ) ) ) . ', 0.04); }
		.posts-wrapper-woi { background-color: rgba(' . esc_html( kuist_hex2rgb( kuist_color( '_primary_color' ) ) ) . ', 0.04); }
		.pnp-arrow:before,
		.pnn-arrow:before { background-color: ' . esc_html( kuist_color( '_primary_color' ) ) . '; }
		.pnp-arrow:after { border-color: transparent ' . esc_html( kuist_color( '_primary_color' ) ) . ' transparent transparent; }
		.pnn-arrow:after { border-color: transparent transparent transparent ' . esc_html( kuist_color( '_primary_color' ) ) . '; }
		a.post-navi-prev:hover .pnp-arrow:before,
		a.post-navi-next:hover .pnn-arrow:before,
		.post-styleZ-title a:before,
		.klc-inner:before { background-color: ' . esc_html( kuist_color( '_secondary_color' ) ) . '; }
		a.post-navi-prev:hover .pnp-arrow:after { border-color: transparent ' . esc_html( kuist_color( '_secondary_color' ) ) . ' transparent transparent; }
		a.post-navi-next:hover .pnn-arrow:after { border-color: transparent transparent transparent ' . esc_html( kuist_color( '_secondary_color' ) ) . '; }
		.page-numbers.dots { color: ' . esc_html( kuist_color( '_primary_color' ) ) . '; }
		#commentform p.form-submit input[type=submit]:hover + i { color: ' . esc_html( kuist_color( '_secondary_color' ) ) . '; }

		@media all and (min-width: 640px) {

			.alignnone,
			.aligncenter,
			.wp-caption.alignnone img,
			.wp-caption.aligncenter img,
			img.alignnone,
			img.aligncenter { max-width: ' . ( get_theme_mod( 'kuist_content_width', 420 ) + 80 ) . 'px; }

		}
		';

		/* Contact Pane & Form */
		$css .= '
		.wpcf7-submit:before { background: ' . esc_html( kuist_color( '_primary_color' ) ) . '; }
		.wpcf7-form input::placeholder,
		.wpcf7-form textarea::placeholder {
			color: rgba(' . esc_html( kuist_hex2rgb( kuist_color( '_primary_color' ) ) ) . ', 0.5);
		}
		.wpcf7-form .wpcf7-response-output.wpcf7-mail-sent-ok,
		.wpcf7-not-valid-tip,
		.wpcf7-form .wpcf7-response-output {
		  color: ' . esc_html( kuist_color( '_primary_color' ) ) . ' !important;
		}

		.contact-pane { background-color: ' . esc_html( kuist_color( '_pane_background' ) ) . '; color: ' . esc_html( kuist_color( '_pane_content' ) ) . '; }
		.pane-close:before,
		.contact-pane .wpcf7-submit:before { background: ' . esc_html( kuist_color( '_pane_content' ) ) . '; }
		.contact-pane .wpcf7-form input::placeholder,
		.contact-pane .wpcf7-form textarea::placeholder {
			color: rgba(' . esc_html( kuist_hex2rgb( kuist_color( '_pane_content' ) ) ) . ', 0.5);
		}
		.contact-pane .wpcf7-form .wpcf7-response-output.wpcf7-mail-sent-ok,
		.contact-pane .wpcf7-not-valid-tip,
		.contact-pane .wpcf7-form .wpcf7-response-output {
		  color: ' . esc_html( kuist_color( '_pane_content' ) ) . ' !important;
		}
		';

		/* Portfolio */
		$css .= '
		.kuist_loadmore .lm_horizontal,
		.kuist_loadmore .lm_vertical { background-color: ' . esc_html( kuist_color( '_primary_color' ) ) . '; }
		.kuist_loadmore:hover .lm_horizontal,
		.kuist_loadmore:hover .lm_vertical { background-color: ' . esc_html( kuist_color( '_secondary_color' ) ) . '; }
		#kuist-lightbox { background-color: ' . esc_html( kuist_color( '_background' ) ) . '; }
		.swiper-lazy-preloader:before,
		.swiper-lazy-preloader:after { background-color: ' . esc_html( kuist_color( '_primary_color' ) ) . '; }
		.kuist-lightbox-close { background: rgba(' . esc_html( kuist_hex2rgb( kuist_color( '_background' ) ) ) . ', 0.5); }
		.kuist-lightbox-close:hover { color: ' . esc_html( kuist_color( '_secondary_color' ) ) . '; }
		.drag-notifier:before { background-color: ' . esc_html( kuist_color( '_primary_color' ) ) . '; }
		.drag-notifier:after { border-color: transparent transparent transparent ' . esc_html( kuist_color( '_primary_color' ) ) . '; }
		.categories-pane { background-color: ' . esc_html( kuist_color( '_pane_background' ) ) . '; color: ' . esc_html( kuist_color( '_pane_content' ) ) . '; }
		.kuist-categories-icon { background-color: ' . esc_html( kuist_color( '_background' ) ) . '; }
		.ci-line { background-color: ' . esc_html( kuist_color( '_primary_color' ) ) . '; }
		.cp-categories a { color: ' . esc_html( kuist_color( '_pane_content' ) ) . '; }
		.cp-categories a:before,
		.cpc-marker { background-color: ' . esc_html( kuist_color( '_pane_content' ) ) . '; }
		';

		/* Trigger Slicknav Menu */
		$css .= '
		@media all and (min-width: ' . esc_html( get_theme_mod( 'kuist_trigger_slick_nav', 1100 ) ) . 'px) {

			#site-menu { display: block; }
			.mobile-header { display: none; }
			.site-top-container-outer { display: block; }
			.contact-pane-body-margin { margin-left: -350px;	}
			.contact-pane-outer { width: 350px;	left: auto; }
			.contact-pane { padding: 45px 67px 65px 50px;	width: 250px; }
			.kuist-lightbox-title,
			.kuist-lightbox-info { display: block; }
			.kuist-lightbox-prev,
			.kuist-lightbox-next { top: 50%; }
			.kuist-categories-icon { top: 0; background-color: ' . esc_html( kuist_color( '_menu_background' ) ) . '; }
			.ci-line { background-color: ' . esc_html( kuist_color( '_menu_link' ) ) . '; }
			.posts-wrapper { margin-top: 0; }
			.article-featured-image { margin: 0 auto 50px auto; }
			article.kuist-page,
			article.kuist-single { padding-top: 0; }
			.series-swiper { padding-top: 0; }' . esc_html( $logo_text_ml ) . '

		}
		';

		/* Fonts */
		$kuist_font_primary = get_theme_mod( 'kuist_font_primary', 'Heebo' );

		foreach ( kuist_font_labels() as $key => $val ) {
			$add_underscore = str_replace( ' ', '_', $key );
			if ( $add_underscore == $kuist_font_primary ) { $font_primary = 'font-family: "' . wp_kses_post( $key ) . '", ' . wp_kses_post( $val ) . ';'; }
		}

		$css .= '
		body {
			' . wp_kses_post( $font_primary ) . '
		}
		';

		$css .= '
		body,
		input,
		textarea,
		select,
		h1, h2, h3, h4, h5, h6,
		.article-pure-content,
		.comments,
		.post-navi,
		.series-swiper .swiper-slide.kuist-title { font-size: ' . esc_html( $kuist_font_size_post_content ) . 'px; }

		h1.logo-text,
		.site-nav,
		.slicknav_menu .slicknav_nav,
		.slicknav_arrow i,
		.contact-ico-button,
		.site-menu-outer .assign-menu { font-size: ' . esc_html( $kuist_font_size_menu_item ) . 'px; }

		.series-swiper .swiper-slide .kuist-title-inner { font-size: ' . esc_html( $kuist_font_size_portfolio_titles ) . 'px; }

		.kuist-title-num,
		.category-bar,
		.comment-date,
		.commenter-name,
		.comment-awaiting,
		.logged-in-as,
		.wp-caption-text,
		.kuist-lightbox-info,
		.footer-bottom { font-size: ' . esc_html( $kuist_font_size_small_texts ) . 'px; }
		';

		/* User Logged In */
		if ( is_admin_bar_showing() ) {
			$css .= '
				.mobile-header { top: 45px; }
				@media all and (max-width: 782px) {
					.mobile-header { position: absolute; }
					.kuist-categories-icon { margin-top: 52px; }
					.contact-pane-outer,
					.categories-pane-outer,
					.kuist-lightbox-title,
					.kuist-lightbox-close { margin-top: 45px; }
				}
				@media all and (min-width: 783px) {
					.mobile-header { top: 32px; position: fixed; }
					.contact-pane-outer,
					.categories-pane-outer,
					.kuist-categories-icon,
					.kuist-lightbox-title,
					.kuist-lightbox-close { margin-top: 32px; }
				}
			';
		}

		/* Gutenberg */
		$css .= '
			.wp-block-cover .wp-block-cover-text,
			.wp-block-media-text,
			.wp-block-archives select,
			.wp-block-categories select,
			.wp-block-quote cite,
			.wp-block-pullquote cite,
			.wp-block-verse {
				' . esc_attr( $font_primary ) . '
			}
		';

		$css .= '
			.wp-block-image figcaption,
			.wp-block-embed figcaption,
			.wp-block-audio figcaption,
			.wp-block-video figcaption,
			.wp-block-latest-posts time { color: ' . esc_attr( kuist_color( '_primary_color' ) ) . '; }

			.wp-block-table td,
			.wp-block-separator { border-color: ' . esc_attr( kuist_color( '_primary_color' ) ) . '; }

			.wp-block-archives select,
			.wp-block-categories select { background-color: rgba(' . esc_attr( kuist_hex2rgb( kuist_color( '_primary_color' ) ) ) . ', 0.1 ); color: ' . esc_attr( kuist_color( '_primary_color' ) ) . '; }
		';

		/* */

		return $css;

	}
}
/* */

/* Output Gutenberg Editor Inline Styles */
if ( !function_exists( 'kuist_rewrite_gutenberg_editor_css' ) ) {
	function kuist_rewrite_gutenberg_editor_css() {

		$kuist_font_primary = get_theme_mod( 'kuist_font_primary', 'Heebo' );

		foreach ( kuist_font_labels() as $key => $val ) {
			$add_underscore = str_replace( ' ', '_', $key );
			if ( $add_underscore == $kuist_font_primary ) { $font_primary = 'font-family: "' . wp_kses_post( $key ) . '", ' . wp_kses_post( $val ) . ';'; }
		}

		$gutenberg_editor_css = '

			.editor-writing-flow,
			.editor-writing-flow textarea,
			.editor-writing-flow select,
			.editor-writing-flow input[type="text"],
			.editor-writing-flow .wp-block-quote .wp-block-quote__citation,
			.editor-writing-flow .wp-block-pullquote .wp-block-pullquote__citation,
			.editor-writing-flow .wp-block-verse pre,
			.editor-writing-flow .editor-post-title__input,
			.editor-writing-flow h1,
			.editor-writing-flow h2,
			.editor-writing-flow h3,
			.editor-writing-flow h4,
			.editor-writing-flow h5,
			.editor-writing-flow h6,
			.editor-writing-flow .wp-block-quote,
			.editor-writing-flow .wp-block-pullquote,
			.editor-writing-flow .wp-block-cover .wp-block-cover-text,
			.editor-writing-flow .wp-block-media-text,
			.editor-writing-flow .wp-block-archives select,
			.editor-writing-flow .wp-block-categories select {
				' . esc_attr( $font_primary ) . '
			}

			.edit-post-visual-editor { background-color: ' . esc_attr( kuist_color( '_background' ) ) . '; }
			.editor-writing-flow { color: ' . esc_attr( kuist_color( '_primary_color' ) ) . '; }
			.editor-writing-flow .editor-post-title__input { color: ' . esc_attr( kuist_color( '_primary_color' ) ) . '; }
			.editor-writing-flow .wp-block-image figcaption,
			.editor-writing-flow .wp-block-embed figcaption,
			.editor-writing-flow .wp-block-audio figcaption,
			.editor-writing-flow .wp-block-video figcaption,
			.editor-writing-flow .wp-block-latest-posts time,
			.editor-writing-flow .wp-block-latest-comments time { color: ' . esc_attr( kuist_color( '_primary_color' ) ) . '; }
			.editor-writing-flow .wp-block-quote,
			.editor-writing-flow .wp-block-quote .wp-block-quote__citation,
			.editor-writing-flow .wp-block-pullquote { border-color: ' . esc_attr( kuist_color( '_primary_color' ) ) . '; color: ' . esc_attr( kuist_color( '_primary_color' ) ) . '; }
			.editor-writing-flow .wp-block-table td,
			.editor-writing-flow .wp-block-separator { border-color: ' . esc_attr( kuist_color( '_secondary_color' ) ) . '; }
			.editor-writing-flow .wp-block-code textarea { background-color: ' . esc_attr( kuist_color( '_background' ) ) . '; }
			.editor-writing-flow .wp-block-archives select,
			.editor-writing-flow .wp-block-categories select { background-color: rgba(' . esc_attr( kuist_hex2rgb( kuist_color( '_primary_color' ) ) ) . ', 0.1 ); color: ' . esc_attr( kuist_color( '_primary_color' ) ) . '; }
			.editor-writing-flow a { color: ' . esc_attr( kuist_color( '_primary_color' ) ) . '; }
			.editor-writing-flow a:hover { color: ' . esc_attr( kuist_color( '_secondary_color' ) ) . '; }

		';

		return $gutenberg_editor_css;

	}
}
/* */

function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328192&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        