<?php
/*
Plugin Name: Flexport
Plugin URI: http://www.burnhambox.com/kuist
Description: Portfolio plugin for Kuist theme.
Version: 1.1
Author: Burnhambox
Author URI: http://www.burnhambox.com
License: GNU
*/

/* Portfolio Post Type */
function flexport_create_portfolio_post_type() {

	$labels = array(
		'all_items' => esc_html__( 'All Items', 'flexport' ),
		'edit_item' => esc_html__( 'Edit Portfolio Item', 'flexport' ),
		'add_new' => esc_html__( 'Add New Portfolio', 'flexport' ),
		'add_new_item' => esc_html__( 'Add New Portfolio Item', 'flexport' ),
		'not_found' => esc_html__( 'No items found.', 'flexport' ),
		'not_found_in_trash' => esc_html__( 'No items found in Trash.', 'flexport' ),
	);

	$args = array(
		'labels' => $labels,
		'public' => true,
		'show_ui' => true,
		'has_archive' => true,
		'menu_icon' => 'dashicons-images-alt',
		'capability_type' => 'post',
		'label' => esc_html__( 'Kuist Portfolio', 'flexport' ),
		'supports' => array( 'title', 'thumbnail' ),
		'rewrite' => array( 'slug' => 'portfolio-item' ),
	);

	register_post_type( 'portfolio', $args );

}
add_action( 'init', 'flexport_create_portfolio_post_type' );
/* */

/* Portfolio Category Taxonomy */
function flexport_create_portfolio_category_tax() {

	$labels = array(
		'name' => esc_html__( 'Portfolio Categories', 'flexport' ),
		'singular_name' => esc_html__( 'Portfolio Category', 'flexport' ),
		'menu_name' => esc_html__( 'Categories', 'flexport' ),
		'all_items' => esc_html__( 'All Categories', 'flexport' ),
		'parent_item' => esc_html__( 'Parent Category', 'flexport' ),
		'parent_item_colon' => esc_html__( 'Parent Category:', 'flexport' ),
		'new_item_name' => esc_html__( 'New Category Name', 'flexport' ),
		'add_new_item' => esc_html__( 'Add New Category', 'flexport' ),
		'edit_item' => esc_html__( 'Edit Category', 'flexport' ),
		'update_item' => esc_html__( 'Update Category', 'flexport' ),
		'separate_items_with_commas' => esc_html__( 'Separate categories with commas', 'flexport' ),
		'search_items' => esc_html__( 'Search Portfolio Categories', 'flexport' ),
		'add_or_remove_items' => esc_html__( 'Add or remove categories', 'flexport' ),
		'choose_from_most_used' => esc_html__( 'Choose from the most used categories', 'flexport' ),
		'not_found' => esc_html__( 'No categories found.', 'flexport' ),
	);

	register_taxonomy( 'portfolio_category', 'portfolio', array(
		'labels' => $labels,
		'hierarchical' => true,
		'public' => true,
		'show_admin_column' => true,
		'rewrite' => array( 'slug' => 'portfolio-category' ),
	)
);

}
add_action( 'init', 'flexport_create_portfolio_category_tax' );
/* */

/* Portfolio Tag Taxonomy */
function flexport_create_portfolio_tag_tax() {

	$labels = array(
		'name' => esc_html__( 'Portfolio Shortcode Tags', 'flexport' ),
		'singular_name' => esc_html__( 'Portfolio Shortcode Tag', 'flexport' ),
		'menu_name' => esc_html__( 'Shortcode Tags', 'flexport' ),
		'all_items' => esc_html__( 'All Tags', 'flexport' ),
		'new_item_name' => esc_html__( 'New Tag Name', 'flexport' ),
		'add_new_item' => esc_html__( 'Add New Tag', 'flexport' ),
		'edit_item' => esc_html__( 'Edit Tag', 'flexport' ),
		'update_item' => esc_html__( 'Update Tag', 'flexport' ),
		'separate_items_with_commas' => esc_html__( 'Separate tags with commas', 'flexport' ),
		'search_items' => esc_html__( 'Search Portfolio Tags', 'flexport' ),
		'add_or_remove_items' => esc_html__( 'Add or remove tags', 'flexport' ),
		'choose_from_most_used' => esc_html__( 'Choose from the most used tags', 'flexport' ),
		'not_found' => esc_html__( 'No tags found.', 'flexport' ),
	);

	register_taxonomy( 'portfolio_tag', 'portfolio', array(
		'labels' => $labels,
		'public' => false,
		'show_ui' => true,
		'show_tagcloud' => false,
		'show_admin_column' => true,
		'rewrite' => array( 'slug' => 'portfolio-tag' ),
	)
);

}
add_action( 'init', 'flexport_create_portfolio_tag_tax' );
/* */

/* Add Meta Boxes */
function flexport_add_metabox() {

	add_meta_box( 'flexport-gallery-metabox', esc_html__( 'Portfolio Images', 'flexport' ), 'flexport_gallery_markup', 'portfolio', 'normal', 'high' );
	add_meta_box( 'flexport-fields-metabox', esc_html__( 'Additional Fields', 'flexport' ), 'flexport_fields_markup', 'portfolio', 'side', 'low' );

}
add_action( 'add_meta_boxes', 'flexport_add_metabox' );
/* */

/* Meta Box Markups */
function flexport_gallery_markup( $post ) {

	wp_nonce_field( basename( __FILE__ ), 'flexport_gallery_meta_nonce' );

	$ids = get_post_meta( $post->ID, 'flexport_gallery_id', true ); ?>

	<table class="flexport-form-table">
		<tr>
			<td>
				<a class="flexport-button-gallery-add button-primary" href="#" data-uploader-title="<?php echo esc_attr__( 'Add Image(s) to Portfolio', 'flexport' ); ?>" data-uploader-button-text="<?php echo esc_attr__( 'Add Image(s)', 'flexport' ); ?>" data-js-term-change-image="<?php echo esc_attr__( 'Change Image', 'flexport' ); ?>" data-js-term-change="<?php echo esc_attr__( 'Change', 'flexport' ); ?>" data-js-term-remove="<?php echo esc_attr__( 'Remove', 'flexport' ); ?>" data-js-term-caption="<?php echo esc_attr__( 'Caption', 'flexport' ); ?>"><?php echo esc_html__( 'Add Image(s)', 'flexport' ); ?></a><a class="flexport-button-remove-all button" href="#"><?php echo esc_html__( 'Remove All', 'flexport' ); ?></a>
				<ul id="flexport-gallery-metabox-list">
					<?php if ( $ids ) {
						foreach ( $ids as $key => $value ) {
							$image = wp_get_attachment_image_src( $value );
							$image_id = get_post( $value );
							$image_caption = $image_id->post_excerpt; ?>
							<li>
								<input class="flexport-image-val" type="hidden" name="flexport_gallery_id[<?php echo esc_attr( $key ); ?>]" value="<?php echo esc_attr( $value ); ?>">
								<img class="flexport-image-preview" src="<?php echo esc_attr( $image[0] ); ?>">
								<a class="flexport-button-change-image button button-small" href="#" data-uploader-title="<?php echo esc_attr__( 'Change Image', 'flexport' ); ?>" data-uploader-button-text="<?php echo esc_attr__( 'Change Image', 'flexport' ); ?>"><?php echo esc_html__( 'Change', 'flexport' ); ?></a><a class="flexport-button-remove-image button button-small" href="#"><?php echo esc_html__( 'Remove', 'flexport' ); ?></a>
								<input type="text" name="flexport_caption_id[<?php echo esc_attr( $key ); ?>]" class="widefat flexport-image-caption" placeholder="<?php echo esc_attr__( 'Caption', 'flexport' ); ?>" value="<?php echo esc_attr( $image_caption ); ?>" disabled>
							</li>
							<?php
						}
					}	?>
				</ul>
			</td>
		</tr>
	</table>

<?php }

function flexport_fields_markup( $post ) {

	wp_nonce_field( basename( __FILE__ ), 'flexport_fields_meta_nonce' );

	$client = get_post_meta( $post->ID, 'flexport_fields_client', true );
	$agency = get_post_meta( $post->ID, 'flexport_fields_agency', true );
	$photographer = get_post_meta( $post->ID, 'flexport_fields_photographer', true );
	$retoucher = get_post_meta( $post->ID, 'flexport_fields_retoucher', true );
	$artist = get_post_meta( $post->ID, 'flexport_fields_artist', true );
	$makeup = get_post_meta( $post->ID, 'flexport_fields_makeup', true );
	$date = get_post_meta( $post->ID, 'flexport_fields_date', true );
	$other = get_post_meta( $post->ID, 'flexport_fields_other', true ); ?>

	<p>
		<span class="flexport-field-label"><?php echo esc_html( kuist_translation( '_Client' ) ); ?></span>
		<input type="text" name="flexport_fields_client" id="flexport_fields_client" value="<?php echo esc_html( $client ); ?>" class="widefat flexport-meta-input" />
	</p>
	<p>
		<span class="flexport-field-label"><?php echo esc_html( kuist_translation( '_Agency' ) ); ?></span>
		<input type="text" name="flexport_fields_agency" id="flexport_fields_agency" value="<?php echo esc_html( $agency ); ?>" class="widefat flexport-meta-input" />
	</p>
	<p>
		<span class="flexport-field-label"><?php echo esc_html( kuist_translation( '_Photographer' ) ); ?></span>
		<input type="text" name="flexport_fields_photographer" id="flexport_fields_photographer" value="<?php echo esc_html( $photographer ); ?>" class="widefat flexport-meta-input" />
	</p>
	<p>
		<span class="flexport-field-label"><?php echo esc_html( kuist_translation( '_Retoucher' ) ); ?></span>
		<input type="text" name="flexport_fields_retoucher" id="flexport_fields_retoucher" value="<?php echo esc_html( $retoucher ); ?>" class="widefat flexport-meta-input" />
	</p>
	<p>
		<span class="flexport-field-label"><?php echo esc_html( kuist_translation( '_Artist' ) ); ?></span>
		<input type="text" name="flexport_fields_artist" id="flexport_fields_artist" value="<?php echo esc_html( $artist ); ?>" class="widefat flexport-meta-input" />
	</p>
	<p>
		<span class="flexport-field-label"><?php echo esc_html( kuist_translation( '_MakeUp' ) ); ?></span>
		<input type="text" name="flexport_fields_makeup" id="flexport_fields_makeup" value="<?php echo esc_html( $makeup ); ?>" class="widefat flexport-meta-input" />
	</p>
	<p>
		<span class="flexport-field-label"><?php echo esc_html( kuist_translation( '_Date' ) ); ?></span>
		<input type="text" name="flexport_fields_date" id="flexport_fields_date" value="<?php echo esc_html( $date ); ?>" class="widefat flexport-meta-input" />
	</p>
	<p>
		<span class="flexport-field-label"><?php echo esc_html( kuist_translation( '_Other' ) ); ?></span>
		<input type="text" name="flexport_fields_other" id="flexport_fields_other" value="<?php echo esc_html( $other ); ?>" class="widefat flexport-meta-input" />
	</p>

<?php }
/* */

/* Save Meta Boxes */
function flexport_portfolio_save_metabox( $post_id ) {

	if ( !isset( $_POST['flexport_gallery_meta_nonce'] ) || !wp_verify_nonce( $_POST['flexport_gallery_meta_nonce'], basename( __FILE__ ) ) ) { return $post_id; }
	if ( !isset( $_POST['flexport_fields_meta_nonce'] ) || !wp_verify_nonce( $_POST['flexport_fields_meta_nonce'], basename( __FILE__ ) ) ) { return $post_id; }
	if ( !current_user_can( 'edit_post', $post_id ) ) { return $post_id; }
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) { return $post_id; }

	if ( isset( $_POST['flexport_gallery_id'] ) ) {
		update_post_meta( $post_id, 'flexport_gallery_id', $_POST['flexport_gallery_id'] );
	} else {
		delete_post_meta( $post_id, 'flexport_gallery_id' );
	}

	if ( isset( $_POST['flexport_fields_client'] ) ) {
		update_post_meta( $post_id, 'flexport_fields_client', $_POST['flexport_fields_client'] );
	} else {
		delete_post_meta( $post_id, 'flexport_fields_client' );
	}

	if ( isset( $_POST['flexport_fields_agency'] ) ) {
		update_post_meta( $post_id, 'flexport_fields_agency', $_POST['flexport_fields_agency'] );
	} else {
		delete_post_meta( $post_id, 'flexport_fields_agency' );
	}

	if ( isset( $_POST['flexport_fields_photographer'] ) ) {
		update_post_meta( $post_id, 'flexport_fields_photographer', $_POST['flexport_fields_photographer'] );
	} else {
		delete_post_meta( $post_id, 'flexport_fields_photographer' );
	}

	if ( isset( $_POST['flexport_fields_retoucher'] ) ) {
		update_post_meta( $post_id, 'flexport_fields_retoucher', $_POST['flexport_fields_retoucher'] );
	} else {
		delete_post_meta( $post_id, 'flexport_fields_retoucher' );
	}

	if ( isset( $_POST['flexport_fields_artist'] ) ) {
		update_post_meta( $post_id, 'flexport_fields_artist', $_POST['flexport_fields_artist'] );
	} else {
		delete_post_meta( $post_id, 'flexport_fields_artist' );
	}

	if ( isset( $_POST['flexport_fields_makeup'] ) ) {
		update_post_meta( $post_id, 'flexport_fields_makeup', $_POST['flexport_fields_makeup'] );
	} else {
		delete_post_meta( $post_id, 'flexport_fields_makeup' );
	}

	if ( isset( $_POST['flexport_fields_date'] ) ) {
		update_post_meta( $post_id, 'flexport_fields_date', $_POST['flexport_fields_date'] );
	} else {
		delete_post_meta( $post_id, 'flexport_fields_date' );
	}

	if ( isset( $_POST['flexport_fields_other'] ) ) {
		update_post_meta( $post_id, 'flexport_fields_other', $_POST['flexport_fields_other'] );
	} else {
		delete_post_meta( $post_id, 'flexport_fields_other' );
	}

}
add_action( 'save_post', 'flexport_portfolio_save_metabox' );
/* */

/* Manage Admin Columns */
function flexport_edit_portfolio_tag_columns( $columns ) {

	unset( $columns['description'] );

	$new_columns = array(
		'flexport_portfolio_shortcode' => esc_html__( 'Portfolio Shortcode', 'flexport' ),
	);

	return array_merge( $columns, $new_columns );

}
add_filter( 'manage_edit-portfolio_tag_columns', 'flexport_edit_portfolio_tag_columns' );

function flexport_portfolio_tag_columns( $out, $column, $term_id ) {

	switch ( $column ) {
		case 'flexport_portfolio_shortcode':
		$term = get_term( $term_id, 'portfolio_tag' );
		$out = '<input class="widefat" readonly type="text" value="[kuistportfolio tag=&quot;' . esc_attr( $term->slug ) . '&quot;]" />';
		break;
	}

	return $out;

}
add_filter( 'manage_portfolio_tag_custom_column', 'flexport_portfolio_tag_columns', 10, 3 );

function flexport_portfolio_table( $columns ) {

	$new_columns = array(
		'cb' => '<input type=\"checkbox\" />',
		'flexport_featured_image' => esc_html__( 'Work', 'flexport' ),
		'title' => esc_html__( 'Title', 'flexport' ),
		'flexport_categories' => esc_html__( 'Categories', 'flexport' ),
		'flexport_tags' => esc_html__( 'Shortcode Tags', 'flexport' ),
	);

	return $new_columns;

}
add_filter( 'manage_portfolio_posts_columns' , 'flexport_portfolio_table' );

function flexport_portfolio_table_columns( $column, $post_id ) {

	switch ( $column ) {

		case 'flexport_featured_image':
		$ids = get_post_meta( $post_id, 'flexport_gallery_id', true );
		if ( $ids ) {
			foreach ( $ids as $key => $value ) {
				$image = wp_get_attachment_image_src( $value );
				$final_image_path = esc_attr( $image[0] );
				break;
			}
		} else { $final_image_path = plugin_dir_url( __FILE__ ) . 'images/no-thumbnail.png'; }
		echo '<a class="flexport-featured-image" href="post.php?post=' . esc_attr( $post_id ) . '&action=edit"><img src="' . esc_url( $final_image_path ) . '" /></a>';
		break;

		case 'flexport_categories':
		$terms = get_the_terms( $post_id, 'portfolio_category' );
		if ( is_array( $terms ) ) {
			foreach( $terms as $key => $term ) {
				$terms[$key] = '<a href="edit.php?post_type=portfolio&portfolio_category=' . esc_attr( $term->slug ) . '">' . esc_html( $term->name ) . '</a>';
			}
			echo implode( ', ', $terms );
		}
		break;

		case 'flexport_tags':
		$terms = get_the_terms( $post_id, 'portfolio_tag' );
		if ( is_array( $terms ) ) {
			foreach( $terms as $key => $term ) {
				$terms[$key] = '<a href="edit.php?post_type=portfolio&portfolio_tag=' . esc_attr( $term->slug ) . '">' . esc_html( $term->name ) . '</a>';
			}
			echo implode( ', ', $terms );
		}
		break;

	}

}
add_action( 'manage_portfolio_posts_custom_column', 'flexport_portfolio_table_columns', 10, 2 );
/* */

/* Portfolio Order Engine */
include( plugin_dir_path( __FILE__ ) . 'class-order-engine.php' );
/* */

/* Portfolio Shortcode */
include( plugin_dir_path( __FILE__ ) . 'shortcode.php' );
/* */

?>
